==> huaweicloudsdkeg-3.1.135-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/put_official_events_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PutOfficialEventsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'source_name': 'str',
        'body': 'PutEventsReq'
    }

    attribute_map = {
        'source_name': 'source_name',
        'body': 'body'
    }

    def __init__(self, source_name=None, body=None):
        """PutOfficialEventsRequest

        The model defined in huaweicloud sdk

        :param source_name: 事件源名称
        :type source_name: str
        :param body: Body of the PutOfficialEventsRequest
        :type body: :class:`huaweicloudsdkeg.v1.PutEventsReq`
        """
        
        

        self._source_name = None
        self._body = None
        self.discriminator = None

        self.source_name = source_name
        if body is not None:
            self.body = body

    @property
    def source_name(self):
        """Gets the source_name of this PutOfficialEventsRequest.

        事件源名称

        :return: The source_name of this PutOfficialEventsRequest.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """Sets the source_name of this PutOfficialEventsRequest.

        事件源名称

        :param source_name: The source_name of this PutOfficialEventsRequest.
        :type source_name: str
        """
        self._source_name = source_name

    @property
    def body(self):
        """Gets the body of this PutOfficialEventsRequest.

        :return: The body of this PutOfficialEventsRequest.
        :rtype: :class:`huaweicloudsdkeg.v1.PutEventsReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this PutOfficialEventsRequest.

        :param body: The body of this PutOfficialEventsRequest.
        :type body: :class:`huaweicloudsdkeg.v1.PutEventsReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PutOfficialEventsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeg-3.1.151-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/put_official_events_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PutOfficialEventsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'source_name': 'str',
        'body': 'PutEventsReq'
    }

    attribute_map = {
        'source_name': 'source_name',
        'body': 'body'
    }

    def __init__(self, source_name=None, body=None):
        r"""PutOfficialEventsRequest

        The model defined in huaweicloud sdk

        :param source_name: 事件源名称
        :type source_name: str
        :param body: Body of the PutOfficialEventsRequest
        :type body: :class:`huaweicloudsdkeg.v1.PutEventsReq`
        """
        
        

        self._source_name = None
        self._body = None
        self.discriminator = None

        self.source_name = source_name
        if body is not None:
            self.body = body

    @property
    def source_name(self):
        r"""Gets the source_name of this PutOfficialEventsRequest.

        事件源名称

        :return: The source_name of this PutOfficialEventsRequest.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        r"""Sets the source_name of this PutOfficialEventsRequest.

        事件源名称

        :param source_name: The source_name of this PutOfficialEventsRequest.
        :type source_name: str
        """
        self._source_name = source_name

    @property
    def body(self):
        r"""Gets the body of this PutOfficialEventsRequest.

        :return: The body of this PutOfficialEventsRequest.
        :rtype: :class:`huaweicloudsdkeg.v1.PutEventsReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this PutOfficialEventsRequest.

        :param body: The body of this PutOfficialEventsRequest.
        :type body: :class:`huaweicloudsdkeg.v1.PutEventsReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PutOfficialEventsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
